abacusai.feature_group_row_process_summary — AbacusAI documentation

# abacusai.feature_group_row_process_summary

## Classes

`AbstractApiClass` |
`FeatureGroupRowProcessSummary` | A summary of the feature group processes for a deployment.

## Module Contents

class abacusai.feature_group_row_process_summary.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.feature_group_row_process_summary.FeatureGroupRowProcessSummary(client, totalProcesses=None, pendingProcesses=None, processingProcesses=None, completeProcesses=None, failedProcesses=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A summary of the feature group processes for a deployment.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - totalProcesses (int) – The total number of processes

    - pendingProcesses (int) – The number of pending processes

    - processingProcesses (int) – The number of processes currently processing

    - completeProcesses (int) – The number of complete processes

    - failedProcesses (int) – The number of failed processes

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict